"""
The ``{{ cookiecutter.base_package }}`` package is:

* Independent of the ``freecad.{{ cookiecutter.base_package }}`` package
* Must not know about the FreeCAD GUI (i.e. ``FreeCADGui`` or ``Gui``)
* Executable from a command-line context
"""
